# load-m3u8

## Import
```
from load_m3u8.resolve import Load_M3U8

Load_M3U8("http://www.youtube.com/test.m3u8").run()
```

## Usage
```
pip --no-cache-dir install load-m3u8

load-m3u8 -mu "http://www.youtube.com/test.m3u8"
```